\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{thesis}[2007/10/19 v1.0]
\LoadClass[12pt,a4paper,BCOR=.7cm,headsepline,bibliography=totoc]{scrbook}
\DeclareOption{MsThesis}{\AtEndOfPackage{\def\per@fordegree{پایان‌نامه کارشناسی ارشد}\def\lat@fordegree{Ms Thesis}}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ProcessOptions
\RequirePackage{amsmath,amsthm,graphicx}
\RequirePackage{arrayjobx,forloop}
%حاشیه در اینجا مشخص می‌شود.
\newlength\OddMarg
\if@twoside
\def\swapmargs{\oddsidemargin\evensidemargin}
\else
\def\swapmargs{
  \OddMarg\paperwidth \addtolength\OddMarg{-\textwidth}
  \addtolength\OddMarg{-\oddsidemargin} \addtolength\OddMarg{-2\hoffset} \addtolength\OddMarg{-2in}
  \oddsidemargin\OddMarg}
\swapmargs
\fi

\parindent2.5em\sloppy
\def\blsfactorfront{1.3}\def\blsfactormain{1.3}
%در ابتدا بایستی فراخوانی شود
\def\START{
  \newdimen\origbls \setlength\origbls\baselineskip \let\latinmaketitle\maketitle
  \usepackage[localise]{xepersian} \FONTS \def\partname{قسمت} \def\bibname{مراجع}
  \renewcommand\headfont{\small\itshape}
  \renewcommand*\sectfont{\normalcolor\bfseries}
  \begin{document}\frontmatter
  \define@titleprops {\ifdefined\TitleFont\TitleFont\fi\renewcommand\titlefont{\Huge\bfseries}\maketitle}
  {\baselineskip\blsfactorfront\baselineskip
    {\pagestyle{empty}\makecanon\makeacknowledge\makeabstract\cleardoubleemptypage}
    {\pagenumbering{tartibi}\pagestyle{plain}\tableofcontents\listoffigures\listoftables  
    \ifdefined\@ppreface\chapter*{پیش‌گفتار}\@ppreface\fi}}
  \baselineskip\blsfactormain\baselineskip\mainmatter}
%در انتها بایستی فراخوانی شود
\def\STOP{
  \cleardoubleemptypage\pagestyle{plain}\baselineskip\origbls \BIBLIO
  \backmatter\pagestyle{empty}\@lattrue\define@titleprops\swapmargs
  \begin{Latin}\makeabstract\latinmaketitle\end{Latin}\end{document}}
%صفحات چکیده و قدردانی
\def\makeabstract{
  \cleardoubleemptypage\begin{center}\Large\bfseries\@ptitle\end{center}
  \subsection*{\@abstname}{\@pabstract} \paragraph*{\@keywordname:}{\@pkeywds.}}
\def\makeacknowledge{
  \ifdefined\@packnow\cleardoubleemptypage\centerline{\Large\bfseries قدردانی}
  \subsection*{}{\@packnow}\fi}
%صفحه تصویب
\def\BSkp{\par\vskip3\bigskipamount} \def\SSkp{\par\vskip\bigskipamount}
\def\signat{امضاء: . . . . . . . . . . .\\[1cm]}
\def\makecanon{\cleardoubleemptypage
  \begin{center}\large\bfseries به نام او \SSkp\@puniv\par\smallskip\@pdepart\end{center}
  \BSkp{\large\@fordegree}\SSkp
  \begin{tabular}{rr} عنوان: & {\large\@ptitle} \\[\medskipamount] \@by: & {\large\@pauthor} \end{tabular}
  \BSkp{\large کمیته داوران}\SSkp
  \begin{center}\begin{tabular*}{.9\textwidth}{r r @{\extracolsep{\fill}} l}
    \@undersup: & {\large\@psupervisor} & \signat
    \ifdefined\@pconsult\@undercons: & {\large\@pconsult} & \signat\fi
    \newcounter{tmp@}
    \forLoop{1}{\value{jury@}}{tmp@}{\jury@titles(\c@tmp@): & {\large\jury@names(\c@tmp@)} & \signat}
&& تاریخ: . . . . . . . . .
  \end{tabular*}\end{center}}
%ابزارهای کمکی نگارش ریاضی
\newcommand\Equation[2][]{\@ifempty{#1}{\begin{align*}#2\end{align*}}{\begin{align}\eqnlabel{#1}#2\end{align}}}
\newcommand\SplitEquation[2][]{\Equation[#1]{\begin{split}#2\end{split}}}
%آدرس‌دهی و برچسب‌گذاری معادلات و شکل‌ها
\def\@table@label{table:}
\def\@fig@label{fig:}
\def\@eqn@label{eqn:}
\newcommand\tablelabel[1]{\label{\@table@label#1}}
\newcommand\figlabel[1]{\label{\@fig@label#1}}
\newcommand\eqnlabel[1]{\label{\@eqn@label#1}}
%استیل‌های قضیه و ارجاع به آنها
\newtheorem{@thm@}{}[chapter]
\renewcommand\the@thm@{\thechapter\@SepMark\arabic{@thm@}}
\newcounter{thms@}
\newcommand\newtheo[2]{
  \stepcounter{thms@} \newtheorem{#1}[@thm@]{#2}
  \expandafter\def\csname @@cntr@@\the\c@thms@\endcsname{#1}
  \expandafter\def\csname @@cntrname@@\the\c@thms@\endcsname{#2}}
\newenvironment{theo}[3][]%
  {\def\@thm@name{#2}\begin{\@thm@name}[#1]\@ifempty{#3}{\relax}{\label{\@thm@name:#3}}}%
  {\end{\@thm@name}}
\newtheo{thm}{قضیه} \newtheo{dfn}{تعریف} \newtheo{ntn}{قرارداد} \newtheo{prp}{گزاره} \newtheo{lem}{لم} \newtheo{rem}{تذکر} \newtheo{cor}{نتیجه} \newtheo{exm}{مثال}
\newcounter{refthm@}
\newcommand\عطف%
[1]{%
  \ifcsname r@\@eqn@label#1\endcsname\hbox{\eqref{\@eqn@label#1}}%
  \else\forLoop{1}{\value{thms@}}{refthm@}{%
    \def\@THTH{\csname @@cntr@@\the\c@refthm@\endcsname}%
    \ifcsname r@\@THTH:#1\endcsname%
    \csname @@cntrname@@\the\c@refthm@\endcsname\space\hbox{\ref{\@THTH:#1}}%
    \setcounter{refthm@}{999}\fi}\ifnum \c@refthm@>\c@thms@%
  \else\ifcsname r@\@fig@label#1\endcsname\figurename\space\hbox{\ref{\@fig@label#1}}%
  \else\ifcsname r@\@table@label#1\endcsname\tablename\space\hbox{\ref{\@table@label#1}}%
  \else\hbox{\ref{#1}}%
  \fi\fi\fi\fi}
%مشخصات پایان‌نامه به فارسی و لاتین
\newif\if@lat
\newcommand\Date[2]{\def\@pdate{\if@lat#2\else#1\fi}}
\newcommand\Author[2]{\def\@pauthor{\if@lat#2\else#1\fi}}
\newcommand\Title[2]{\def\@ptitle{\if@lat#2\else#1\fi}}
\newcommand\University[2]{\def\@puniv{\if@lat#2\else#1\fi}}
\newcommand\Depart[2]{\def\@pdepart{\if@lat#2\else#1\fi}}
\newcommand\Degree[2]{\def\@pdegree{\if@lat#2\else#1\fi}}
\newcommand\Supervisor[2]{\def\@psupervisor{\if@lat#2\else#1\fi}}
\newcommand\Consult[2]{\def\@pconsult{\if@lat#2\else#1\fi}}
\newcommand\Abstract[2]{\def\@pabstract{\if@lat#2\else#1\fi}}
\newcommand\Keywords[2]{\def\@pkeywds{\if@lat#2\else#1\fi}}
\newcommand\Acknowledge[1]{\def\@packnow{#1}}
\newcommand\Preface[1]{\def\@ppreface{#1}}
\newcounter{jury@}\newarray\jury@titles\newarray\jury@names
\newcommand\Jury[2]{\stepcounter{jury@}\jury@titles(\c@jury@)={#1}\jury@names(\c@jury@)={#2}}

\def\define@titleprops{
  \def\@titlehead{\centering\includegraphics{logo}\par\smallskip{\large\@puniv\par\smallskip\@pdepart}}
  \def\@subject{\@fordegree\\[\smallskipamount]\@pdegree} \def\@title{\@ptitle}
  \def\@author{{\normalsize\@by}\\[\smallskipamount]{\@pauthor} \\[2\bigskipamount]%
    {\normalsize\@undersup}\\[\smallskipamount]{\itshape\@psupervisor}%
    \ifdefined\@pconsult\\[2\bigskipamount]{\normalsize\@undercons}\\[\smallskipamount]{\itshape\@pconsult}\fi
    \\[2\bigskipamount]}
  \def\@date{\ifdefined\@pdate\@pdate\else\if@lat\latintoday\else\today\fi\fi}
  \if@lat \def\@abstname{Abstract} \def\@keywordname{Keywords} \def\@by{By} \def\@fordegree{\lat@fordegree} \def\@undersup{Supervisor} \def\@undercons{Under consult of}
  \else \def\@abstname{چکیده} \def\@keywordname{واژه‌های کلیدی} \def\@by{نگارش} \def\@fordegree{\per@fordegree} \def\@undersup{استاد راهنما} \def\@undercons{استاد مشاور}
  \fi
}
\def\per@fordegree{پایان‌نامه دکتری}\def\lat@fordegree{PhD Thesis}